==> nextcloud-31.0.12.tar.bz2: nextcloud/apps/federation/l10n/ga.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Curtha leis an liosta freastalaithe iontaofa",
    "No server found with ID: %s" : "Níor aimsíodh aon fhreastalaí a bhfuil ID air: %s",
    "Could not remove server" : "Níorbh fhéidir an freastalaí a bhaint",
    "Server is already in the list of trusted servers." : "Tá an freastalaí ar liosta na bhfreastalaithe iontaofa cheana féin.",
    "No server to federate with found" : "Níor aimsíodh aon fhreastalaí le cónascadh leis",
    "Could not add server" : "Níorbh fhéidir an freastalaí a chur leis",
    "Trusted servers" : "Freastalaithe iontaofa",
    "Federation" : "Cónaidhm",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Ceadaíonn Cónaidhm duit nascadh le freastalaithe iontaofa eile chun an t-eolaire cuntais a mhalartú.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Ceadaíonn Cónaidhm duit nascadh le freastalaithe iontaofa eile chun an t-eolaire cuntais a mhalartú. Mar shampla, úsáidfear é seo chun cuntais sheachtracha a uathchríochnú le haghaidh comhroinnte cónasctha.",
    "External documentation for Federated Cloud Sharing" : "Doiciméadú seachtrach maidir le Comhroinnt Néalríomhaireachta",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Ceadaíonn Cónaidhm duit nascadh le freastalaithe iontaofa eile chun an t-eolaire cuntais a mhalartú. Mar shampla, úsáidfear é seo chun cuntais sheachtracha a uathchríochnú le haghaidh comhroinnte cónasctha. Ní gá freastalaí a chur leis mar fhreastalaí iontaofa chun sciar cónasctha a chruthú.",
    "Each server must validate the other. This process may require a few cron cycles." : "Ní mór do gach freastalaí an ceann eile a bhailíochtú. D'fhéadfadh go mbeadh cúpla timthriall cron ag teastáil don phróiseas seo.",
    "+ Add trusted server" : "+ Cuir freastalaí iontaofa leis",
    "Trusted server" : "Freastalaí iontaofa",
    "Add" : "Cuir"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-31.0.14.tar.bz2: nextcloud/apps/federation/l10n/ga.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Curtha leis an liosta freastalaithe iontaofa",
    "No server found with ID: %s" : "Níor aimsíodh aon fhreastalaí a bhfuil ID air: %s",
    "Could not remove server" : "Níorbh fhéidir an freastalaí a bhaint",
    "Server is already in the list of trusted servers." : "Tá an freastalaí ar liosta na bhfreastalaithe iontaofa cheana féin.",
    "No server to federate with found" : "Níor aimsíodh aon fhreastalaí le cónascadh leis",
    "Could not add server" : "Níorbh fhéidir an freastalaí a chur leis",
    "Trusted servers" : "Freastalaithe iontaofa",
    "Federation" : "Cónaidhm",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Ceadaíonn Cónaidhm duit nascadh le freastalaithe iontaofa eile chun an t-eolaire cuntais a mhalartú.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Ceadaíonn Cónaidhm duit nascadh le freastalaithe iontaofa eile chun an t-eolaire cuntais a mhalartú. Mar shampla, úsáidfear é seo chun cuntais sheachtracha a uathchríochnú le haghaidh comhroinnte cónasctha.",
    "Could not add trusted server. Please try again later." : "Níorbh fhéidir freastalaí iontaofa a chur leis. Déan iarracht arís ar ball.",
    "Add trusted server" : "Cuir freastalaí iontaofa leis",
    "Server url" : "URL an fhreastalaí",
    "Add" : "Cuir",
    "Server ok" : "Freastalaí ceart go leor",
    "User list was exchanged at least once successfully with the remote server." : "Malartaíodh liosta úsáideoirí uair amháin ar a laghad go rathúil leis an bhfreastalaí cianda.",
    "Server pending" : "Freastalaí ar feitheamh",
    "Waiting for shared secret or initial user list exchange." : "Ag fanacht le rún comhroinnte nó le malartú tosaigh liosta úsáideoirí.",
    "Server access revoked" : "Rochtain ar an bhfreastalaí curtha ar ceal",
    "Server failure" : "Teip freastalaí",
    "Connection to the remote server failed or the remote server is misconfigured." : "Theip ar an gceangal leis an bhfreastalaí cianda nó tá an freastalaí cianda míchumraithe.",
    "Failed to delete trusted server. Please try again later." : "Theip ar an bhfreastalaí iontaofa a scriosadh. Déan iarracht arís ar ball.",
    "Delete" : "Scrios",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Ceadaíonn Cónaidhm duit nascadh le freastalaithe iontaofa eile chun an t-eolaire cuntais a mhalartú. Mar shampla, úsáidfear é seo chun cuntais sheachtracha a uathchríochnú le haghaidh comhroinnte cónasctha. Ní gá freastalaí a chur leis mar fhreastalaí iontaofa chun sciar cónasctha a chruthú.",
    "Each server must validate the other. This process may require a few cron cycles." : "Ní mór do gach freastalaí an ceann eile a bhailíochtú. D'fhéadfadh go mbeadh cúpla timthriall cron ag teastáil don phróiseas seo.",
    "External documentation for Federated Cloud Sharing" : "Doiciméadú seachtrach maidir le Comhroinnt Néalríomhaireachta",
    "+ Add trusted server" : "+ Cuir freastalaí iontaofa leis",
    "Trusted server" : "Freastalaí iontaofa"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
